==> jc-1.4.0.tar.gz: soot/util/TrustingMonotonicArraySet__24ArrayIterator.h <==
// class soot.util.TrustingMonotonicArraySet$ArrayIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1ebb00a4f2ee7900 soot_util_TrustingMonotonicArraySet__24ArrayIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_TrustingMonotonicArraySet__24ArrayIterator_H_
#define _JC_soot_util_TrustingMonotonicArraySet__24ArrayIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_TrustingMonotonicArraySet$object;

// Typedefs
typedef struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_refs	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_refs;
typedef struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_nonrefs	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_nonrefs;
typedef struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$refs	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$refs;
typedef struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$nonrefs	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$nonrefs;
typedef struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object;

typedef const struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vmethods	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vmethods;
typedef const struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtable	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtable;
typedef const struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtype	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtype;

// Constructors
extern void _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$method$_init$9d4baf487512e658(_jc_env *, struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object *, struct _jc_soot_util_TrustingMonotonicArraySet$object *);

// Virtual methods
extern jboolean _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object *);
extern void _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object *);
};

// Vtable
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vmethods	soot_util_TrustingMonotonicArraySet__24ArrayIterator;
};

// Vtype
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtype {
	_jc_type			type;
	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_refs {
	struct _jc_soot_util_TrustingMonotonicArraySet$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$refs {
    _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_refs	soot_util_TrustingMonotonicArraySet__24ArrayIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_nonrefs {
	jint	nextIndex;
};

// Non-reference instance fields (object)
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_nonrefs	soot_util_TrustingMonotonicArraySet__24ArrayIterator;
};

// Object instance structure
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object {
	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtype	*vtype;
	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtype _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_TrustingMonotonicArraySet__24ArrayIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$class_object;

#endif	/* _JC_soot_util_TrustingMonotonicArraySet__24ArrayIterator_H_ */

==> jc-1.4.6.tar.gz: soot/util/TrustingMonotonicArraySet__24ArrayIterator.h <==
// class soot.util.TrustingMonotonicArraySet$ArrayIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1ebb00a4f2ee7900 soot_util_TrustingMonotonicArraySet__24ArrayIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_TrustingMonotonicArraySet__24ArrayIterator_H_
#define _JC_soot_util_TrustingMonotonicArraySet__24ArrayIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_TrustingMonotonicArraySet$object;

// Typedefs
typedef struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_refs	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_refs;
typedef struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_nonrefs	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_nonrefs;
typedef struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$refs	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$refs;
typedef struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$nonrefs	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$nonrefs;
typedef struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object;

typedef const struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vmethods	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vmethods;
typedef const struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtable	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtable;
typedef const struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtype	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtype;

// Constructors
extern void _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$method$_init$9d4baf487512e658(_jc_env *, struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object *, struct _jc_soot_util_TrustingMonotonicArraySet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vmethods	soot_util_TrustingMonotonicArraySet__24ArrayIterator;
};

// Vtype
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtype {
	_jc_type			type;
	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_refs {
	struct _jc_soot_util_TrustingMonotonicArraySet$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$refs {
    _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_refs	soot_util_TrustingMonotonicArraySet__24ArrayIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_nonrefs {
	jint	nextIndex;
};

// Non-reference instance fields (object)
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$sub_nonrefs	soot_util_TrustingMonotonicArraySet__24ArrayIterator;
};

// Object instance structure
struct _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$object {
	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtype	*vtype;
	_jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$vtype _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_TrustingMonotonicArraySet__24ArrayIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_TrustingMonotonicArraySet__24ArrayIterator$class_object;

#endif	/* _JC_soot_util_TrustingMonotonicArraySet__24ArrayIterator_H_ */
